@@ -10,7 +10,7 @@ from django.template.loader import render_to_string
 from django.views.generic import FormView, TemplateView
 
 
-from contato.forms import ContactForm
+from contato.forms import AntiSpamContactForm, ContactForm
 
 
 class SentView(TemplateView):
@@ -98,8 +98,11 @@ class ContactView(BaseContactView):
 
     def get_body(self, form_data):
         message = form_data.get('message')
-        phone_number = form_data.get('phone_number', None)
         template = self.get_body_template()
-        context = dict(message=message, phone_number=phone_number)
+        context = dict(message=message)
         string = render_to_string(template, context)
         return string.lstrip()
+
+
+class AntiSpamContactView(ContactView):
+    form_class = AntiSpamContactForm
